searchData={"items":[{"type":"module","title":"NervesUEvent","doc":"NervesUEvent listens for events from the Linux kernel, automatically loads\ndevice drivers, and forwards them to your Elixir programs.\n\nNervesUEvent is a very simple version of the Linux `udevd`. Just like `udevd`\ndoes for desktop Linux, NervesUEvent registers to receive UEvents from the Linux\nkernel. Unlike `udevd`, NervesUEvent only runs `modprobe` when needed and keeps\ntrack of what hardware is in the system. For most Nerves use cases, `udevd`\nisn't needed.","ref":"NervesUEvent.html"},{"type":"function","title":"NervesUEvent.get/2","doc":"Get the most recent  value of UEvent report\n\nFor example,\n\n```elixir\n> NervesUEvent.get([\"devices\", \"platform\", \"leds\", \"leds\", \"red:indicator-1\"])\n%{\n  \"of_compatible_n\" => \"0\",\n  \"of_fullname\" => \"/leds/rgb1-blue\",\n  \"of_name\" => \"rgb1-blue\",\n  \"subsystem\" => \"leds\"\n}}\n```","ref":"NervesUEvent.html#get/2"},{"type":"function","title":"NervesUEvent.get_all/0","doc":"Get all reported UEvents","ref":"NervesUEvent.html#get_all/0"},{"type":"function","title":"NervesUEvent.match/1","doc":"Run an arbitrary match against UEvents\n\nUse `:_` in the path to accept any value in that position\nUse `:\"$\"` at the end of the path to perform an exact match","ref":"NervesUEvent.html#match/1"},{"type":"function","title":"NervesUEvent.subscribe/1","doc":"Subscribe to uevent notifications\n\nPass a pattern like one you'd pass to `match/1`. Instead of getting a\nresponse, you'll receive a message when a matching UEvent happens.","ref":"NervesUEvent.html#subscribe/1"},{"type":"module","title":"NervesUEvent.UEvent","doc":"GenServer that captures Linux uevent messages and passes them up to Elixir.","ref":"NervesUEvent.UEvent.html"},{"type":"function","title":"NervesUEvent.UEvent.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NervesUEvent.UEvent.html#child_spec/1"},{"type":"type","title":"NervesUEvent.UEvent.option/0","doc":"","ref":"NervesUEvent.UEvent.html#t:option/0"},{"type":"function","title":"NervesUEvent.UEvent.start_link/1","doc":"","ref":"NervesUEvent.UEvent.html#start_link/1"},{"type":"extras","title":"NervesUEvent","doc":"# NervesUEvent\n\n[![CircleCI](https://dl.circleci.com/status-badge/img/gh/nerves-project/nerves_uevent/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/nerves-project/nerves_uevent/tree/main)\n[![Hex version](https://img.shields.io/hexpm/v/nerves_uevent.svg \"Hex version\")](https://hex.pm/packages/nerves_uevent)\n[![REUSE status](https://api.reuse.software/badge/github.com/nerves-project/nerves_uevent)](https://api.reuse.software/info/github.com/nerves-project/nerves_uevent)\n\nNervesUEvent listens for events from the Linux kernel, automatically loads\ndevice drivers, and forwards them to your Elixir programs.\n\nNervesUEvent is a very simple version of the Linux `udevd`. Just like `udevd`\ndoes for desktop Linux, NervesUEvent registers to receive UEvents from the Linux\nkernel. Unlike `udevd`, NervesUEvent only runs `modprobe` when needed and keeps\ntrack of what hardware is in the system. For most Nerves use cases, `udevd`\nisn't needed.\n\n> #### Warning {: .warning}\n>\n> Almost all Nerves systems require some kernel modules to be automatically\n> loaded or critical functionality won't work. WiFi device drivers, for example,\n> are almost always kernel modules. If you're not using NervesUEvent or `udevd`\n> or some other library that automatically loads kernel modules, you'll need to\n> add calls to `modprobe` to your application.\n\nNerves projects generally depend on either `:nerves_uevent` or a version of\n[`:nerves_runtime`](https://hex.pm/packages/nerves_runtime) that included\nsimilar functionality. It's an advanced use case to modify this dependency.","ref":"readme.html"},{"type":"extras","title":"Configuration - NervesUEvent","doc":"NervesUEvent automatically starts on boot. Configuration is supplied via\napplication config. The following option is available:\n\n* `:autoload_modules` - defaults to `true` to automatically run `modprobe` when\n  needed\n\nHere's a `config.exs` example:\n\n```elixir\nconfig :nerves_uevent, autoload_modules: false\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - NervesUEvent","doc":"NervesUEvent is currently very low level in what it reports and reflects the\nLinux representation. For example, say that you're interested in an MMC device\nand you've found out that Linux exposes it in the\n`/sys/devices/platform/soc/2100000.bus/2194000.mmc` directory. Linux also sends\nUEvent messages for all devices in `/sys/device`, so NervesUEvent will know\nabout this too. To query NervesUEvent for device information, drop `/sys` off\nthe path and convert to a list of strings like this:\n\n```elixir\niex> NervesUEvent.get([\"devices\", \"platform\", \"soc\", \"2100000.bus\", \"2190000.mmc\"])\n%{\n  \"driver\" => \"sdhci-esdhc-imx\",\n  \"modalias\" => \"of:NmmcT(null)Cfsl,imx6ull-usdhcCfsl,imx6sx-usdhc\",\n  \"of_alias_0\" => \"mmc1\",\n  \"of_compatible_0\" => \"fsl,imx6ull-usdhc\",\n  \"of_compatible_1\" => \"fsl,imx6sx-usdhc\",\n  \"of_compatible_n\" => \"2\",\n  \"of_fullname\" => \"/soc/bus@2100000/mmc@2190000\",\n  \"of_name\" => \"mmc\",\n  \"subsystem\" => \"platform\"\n}\n```\n\nSome devices have more useful information than others. This particular one\nmostly shows information found in the device tree file for this device. Of note\nis the `\"modalias\"` key. When NervesUEvent sees this, it will try to load the\nappropriate Linux kernel driver for this device if one exists.\n\nMore usefully, you can subscribe for events. For example, if you'd like to be\nnotified when a MicroSD card has been inserted, you can subscribe to all events\non that device:\n\n```elixir\niex> NervesUEvent.subscribe([\"devices\", \"platform\", \"soc\", \"2100000.bus\", \"2190000.mmc\"])\n```\n\nIf you're not sure what to subscribe to, subscribe to all events to see what happens:\n\n```elixir\niex> NervesUEvent.subscribe([])\n```\n\nNow if you physically insert a MicroSD card, NervesUEvent will send messages to\nyour process mailbox. Here's one of the events:\n\n```elixir\niex> flush\n%PropertyTable.Event{\n  table: NervesUEvent,\n  timestamp: 2558213871126,\n  property: [\"devices\", \"platform\", \"soc\", \"2100000.bus\", \"2190000.mmc\", \"mmc_host\", \"mmc0\", \"mmc0:1234\"],\n  value: %{\n    \"mmc_name\" => \"SA04G\",\n    \"mmc_type\" => \"SD\",\n    \"modalias\" => \"mmc:block\",\n    \"subsystem\" => \"mmc\"\n  },\n  previous_timestamp: nil,\n  previous_value: nil\n}\n```\n\nThe primary fields of interest are `:table`, `:timestamp`, `:property`, and\n`:value`. NervesUEvent uses the PropertyTable library for storing everything and\npublishing changes. The timestamps are from `System.monotonic_time/0`.","ref":"readme.html#usage"},{"type":"extras","title":"License - NervesUEvent","doc":"All original source code in this project is licensed under Apache-2.0.\n\nAdditionally, this project follows the [REUSE recommendations](https://reuse.software)\nand labels so that licensing and copyright are clear at the file level.\n\nExceptions to Apache-2.0 licensing are:\n\n* Configuration and data files are licensed under CC0-1.0\n* Documentation is CC-BY-4.0","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.1 - 2025-01-06 - Changelog","doc":"* Updates\n  * Allow `property_table` v0.3.x to be used\n  * Add REUSE compliance\n  * Test with latest libraries and Elixir 1.18. This release also removes\n    official support for Elixir 1.9-1.12. Nothing is known to break those\n    versions, but they also aren't regularly tested.","ref":"changelog.html#v0-1-1-2025-01-06"},{"type":"extras","title":"v0.1.0 - 2022-04-26 - Changelog","doc":"Extract UEvent code from\n[Nerves.Runtime](https://hex.pm/packages/nerves_runtime) and update to use the\n[PropertyTable](https://hex.pm/packages/property_table) library.","ref":"changelog.html#v0-1-0-2022-04-26"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}